@@ -46,7 +46,7 @@ def _get_page_titles(artist, title):
         "format": "json",
         }
     
-    titles = ["%s:%s" %(artist.title(), title.title())]
+    titles = ["%s:%s" %(artist, title), "%s:%s" %(artist.title(), title.title())]
     content = json.loads(_download(args))
     for t in content["query"]["search"]:
         titles.append(t["title"])
@@ -105,5 +105,3 @@ def get_lyrics(artist, title, cache_dir=None):
         fp.close()
     
     return lyrics
-
-print get_lyrics("wolfmother", "eyes open")
